@@ -63,6 +63,7 @@ mod tests {
         all_compile = false
         always_keep_download = true
         always_keep_install = true
+        aqua_registry_url = "https://github.com/aquaproj/aqua-registry"
         asdf_compat = false
         cache_prune_age = "0"
         color = true
@@ -93,8 +94,14 @@ mod tests {
         raw = false
         task_timings = false
         trusted_config_paths = []
+        unix_default_file_shell_args = ["sh"]
+        unix_default_inline_shell_args = ["sh", "-c"]
+        use_file_shell_for_executable_tasks = false
         use_versions_host = true
         verbose = true
+        windows_default_file_shell_args = ["cmd", "/c"]
+        windows_default_inline_shell_args = ["cmd", "/c"]
+        windows_executable_extensions = ["exe", "bat", "cmd", "com", "ps1", "vbs"]
         yes = true
 
         [cargo]
@@ -102,6 +109,9 @@ mod tests {
 
         [node]
 
+        [npm]
+        bun = false
+
         [pipx]
         uvx = false
 
@@ -132,6 +142,7 @@ mod tests {
         all_compile
         always_keep_download
         always_keep_install
+        aqua_registry_url
         asdf_compat
         cache_prune_age
         cargo
@@ -158,6 +169,8 @@ mod tests {
         lockfile
         node
         not_found_auto_install
+        npm
+        npm.bun
         paranoid
         pin
         pipx
@@ -181,8 +194,14 @@ mod tests {
         status.show_tools
         task_timings
         trusted_config_paths
+        unix_default_file_shell_args
+        unix_default_inline_shell_args
+        use_file_shell_for_executable_tasks
         use_versions_host
         verbose
+        windows_default_file_shell_args
+        windows_default_inline_shell_args
+        windows_executable_extensions
         yes
         ");
     }
