@@ -129,6 +129,7 @@ pub mod tests {
         all_compile = false
         always_keep_download = true
         always_keep_install = true
+        aqua_registry_url = "https://github.com/aquaproj/aqua-registry"
         asdf_compat = false
         cache_prune_age = "0"
         color = true
@@ -159,8 +160,14 @@ pub mod tests {
         raw = false
         task_timings = false
         trusted_config_paths = []
+        unix_default_file_shell_args = ["sh"]
+        unix_default_inline_shell_args = ["sh", "-c"]
+        use_file_shell_for_executable_tasks = false
         use_versions_host = true
         verbose = true
+        windows_default_file_shell_args = ["cmd", "/c"]
+        windows_default_inline_shell_args = ["cmd", "/c"]
+        windows_executable_extensions = ["exe", "bat", "cmd", "com", "ps1", "vbs"]
         yes = true
 
         [cargo]
@@ -168,6 +175,9 @@ pub mod tests {
 
         [node]
 
+        [npm]
+        bun = false
+
         [pipx]
         uvx = false
 
