@@ -10,7 +10,7 @@ use serde::de::Visitor;
 use serde::{de, Deserializer};
 use serde_derive::Deserialize;
 use tera::Context as TeraContext;
-use toml_edit::{table, value, Array, DocumentMut, InlineTable, Item, Value};
+use toml_edit::{table, value, Array, DocumentMut, InlineTable, Item, Key, Value};
 use versions::Versioning;
 
 use crate::cli::args::{BackendArg, ToolVersionType};
@@ -18,8 +18,9 @@ use crate::config::config_file::toml::{deserialize_arr, deserialize_path_entry_a
 use crate::config::config_file::{trust_check, ConfigFile, TaskConfig};
 use crate::config::env_directive::{EnvDirective, PathEntry};
 use crate::config::settings::SettingsPartial;
-use crate::config::AliasMap;
+use crate::config::{Alias, AliasMap};
 use crate::file::{create_dir_all, display_path};
+use crate::registry::REGISTRY_BACKEND_MAP;
 use crate::task::Task;
 use crate::tera::{get_tera, BASE_CONTEXT};
 use crate::toolset::{ToolRequest, ToolRequestSet, ToolSource, ToolVersionOptions};
@@ -39,7 +40,7 @@ pub struct MiseToml {
     env: EnvList,
     #[serde(default, deserialize_with = "deserialize_arr")]
     env_path: Vec<PathEntry>,
-    #[serde(default, deserialize_with = "deserialize_alias")]
+    #[serde(default)]
     alias: AliasMap,
     #[serde(skip)]
     doc: OnceCell<DocumentMut>,
@@ -119,8 +120,9 @@ impl MiseToml {
 
     pub fn set_alias(&mut self, fa: &BackendArg, from: &str, to: &str) -> eyre::Result<()> {
         self.alias
-            .entry(fa.clone())
+            .entry(fa.short.to_string())
             .or_default()
+            .versions
             .insert(from.into(), to.into());
         self.doc_mut()?
             .entry("alias")
@@ -131,6 +133,10 @@ impl MiseToml {
             .or_insert_with(table)
             .as_table_like_mut()
             .unwrap()
+            .entry("versions")
+            .or_insert_with(table)
+            .as_table_like_mut()
+            .unwrap()
             .insert(from, value(to));
         Ok(())
     }
@@ -141,12 +147,17 @@ impl MiseToml {
             .get_mut("alias")
             .and_then(|v| v.as_table_mut())
         {
-            if let Some(plugin_aliases) = aliases
+            if let Some(alias) = aliases
                 .get_mut(&fa.to_string())
                 .and_then(|v| v.as_table_mut())
             {
-                plugin_aliases.remove(from);
-                if plugin_aliases.is_empty() {
+                if let Some(versions) = alias.get_mut("versions").and_then(|v| v.as_table_mut()) {
+                    versions.remove(from);
+                    if versions.is_empty() {
+                        alias.remove("versions");
+                    }
+                }
+                if alias.is_empty() {
                     aliases.remove(&fa.to_string());
                 }
             }
@@ -154,10 +165,10 @@ impl MiseToml {
                 self.doc_mut()?.as_table_mut().remove("alias");
             }
         }
-        if let Some(aliases) = self.alias.get_mut(fa) {
-            aliases.remove(from);
-            if aliases.is_empty() {
-                self.alias.remove(fa);
+        if let Some(aliases) = self.alias.get_mut(&fa.short) {
+            aliases.versions.swap_remove(from);
+            if aliases.versions.is_empty() && aliases.full.is_none() {
+                self.alias.swap_remove(&fa.short);
             }
         }
         Ok(())
@@ -168,9 +179,10 @@ impl MiseToml {
             .doc_mut()?
             .entry("env")
             .or_insert_with(table)
-            .as_table_like_mut()
+            .as_table_mut()
             .unwrap();
-        env_tbl.insert(key, toml_edit::value(value));
+        let key = get_key_with_decor(env_tbl, key);
+        env_tbl.insert_formatted(&key, toml_edit::value(value));
         Ok(())
     }
 
@@ -179,7 +191,7 @@ impl MiseToml {
             .doc_mut()?
             .entry("env")
             .or_insert_with(table)
-            .as_table_like_mut()
+            .as_table_mut()
             .unwrap();
         env_tbl.remove(key);
         Ok(())
@@ -285,11 +297,23 @@ impl ConfigFile for MiseToml {
         versions: &[(String, ToolVersionOptions)],
     ) -> eyre::Result<()> {
         let existing = self.tools.entry(fa.clone()).or_default();
+        let output_empty_opts = |opts: &ToolVersionOptions| {
+            if let Some(reg_ba) = REGISTRY_BACKEND_MAP
+                .get(fa.short.as_str())
+                .and_then(|b| b.first())
+            {
+                if reg_ba.opts.as_ref().is_some_and(|o| o == opts) {
+                    // in this case the options specified are the same as in the registry so output no options and rely on the defaults
+                    return true;
+                }
+            }
+            opts.is_empty()
+        };
         existing.0 = versions
             .iter()
             .map(|(v, opts)| MiseTomlTool {
                 tt: ToolVersionType::Version(v.clone()),
-                options: if !opts.is_empty() {
+                options: if !output_empty_opts(opts) {
                     Some(opts.clone())
                 } else {
                     None
@@ -303,24 +327,29 @@ impl ConfigFile for MiseToml {
             .as_table_mut()
             .unwrap();
 
+        // create a key from the short name preserving any decorations like prefix/suffix if the key already exists
+        let key = get_key_with_decor(tools, fa.short.as_str());
+
         // if a short name is used like "node", make sure we remove any long names like "core:node"
-        tools.remove(&fa.full.to_string());
+        if fa.short != fa.full {
+            tools.remove(&fa.full.to_string());
+        }
 
         if versions.len() == 1 {
-            if versions[0].1.is_empty() {
-                tools.insert(&fa.short, value(versions[0].0.clone()));
+            if output_empty_opts(&versions[0].1) {
+                tools.insert_formatted(&key, value(versions[0].0.clone()));
             } else {
                 let mut table = InlineTable::new();
                 table.insert("version", versions[0].0.to_string().into());
                 for (k, v) in &versions[0].1 {
                     table.insert(k, v.clone().into());
                 }
-                tools.insert(&fa.short, table.into());
+                tools.insert_formatted(&key, table.into());
             }
         } else {
             let mut arr = Array::new();
             for (v, opts) in versions {
-                if opts.is_empty() {
+                if output_empty_opts(opts) {
                     arr.push(v.to_string());
                 } else {
                     let mut table = InlineTable::new();
@@ -331,7 +360,7 @@ impl ConfigFile for MiseToml {
                     arr.push(table);
                 }
             }
-            tools.insert(&fa.short, Item::Value(Value::Array(arr)));
+            tools.insert_formatted(&key, Item::Value(Value::Array(arr)));
         }
 
         Ok(())
@@ -382,16 +411,22 @@ impl ConfigFile for MiseToml {
             .clone()
             .iter()
             .map(|(k, v)| {
-                let k = k.clone();
-                let v: Result<BTreeMap<String, String>, eyre::Error> = v
+                let versions = v
                     .clone()
+                    .versions
                     .into_iter()
                     .map(|(k, v)| {
                         let v = self.parse_template(&v)?;
-                        Ok((k, v))
+                        Ok::<(String, String), eyre::Report>((k, v))
                     })
-                    .collect();
-                v.map(|v| (k, v))
+                    .collect::<eyre::Result<IndexMap<_, _>>>()?;
+                Ok((
+                    k.clone(),
+                    Alias {
+                        full: v.full.clone(),
+                        versions,
+                    },
+                ))
             })
             .collect()
     }
@@ -405,6 +440,21 @@ impl ConfigFile for MiseToml {
     }
 }
 
+/// Returns a [`toml_edit::Key`] from the given `key`.
+/// Preserves any surrounding whitespace (e.g. comments) if the key already exists in the provided [`toml_edit::Table`].
+fn get_key_with_decor(table: &toml_edit::Table, key: &str) -> Key {
+    let mut key = Key::from(key);
+    if let Some((k, _)) = table.get_key_value(&key) {
+        if let Some(prefix) = k.leaf_decor().prefix() {
+            key.leaf_decor_mut().set_prefix(prefix.clone());
+        }
+        if let Some(suffix) = k.leaf_decor().suffix() {
+            key.leaf_decor_mut().set_suffix(suffix.clone());
+        }
+    }
+    key
+}
+
 impl Debug for MiseToml {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         let tools = self.to_tool_request_set().unwrap().to_string();
@@ -906,35 +956,55 @@ impl<'de> de::Deserialize<'de> for BackendArg {
     }
 }
 
-fn deserialize_alias<'de, D>(deserializer: D) -> Result<AliasMap, D::Error>
-where
-    D: Deserializer<'de>,
-{
-    struct AliasMapVisitor;
+impl<'de> de::Deserialize<'de> for Alias {
+    fn deserialize<D>(deserializer: D) -> std::result::Result<Self, D::Error>
+    where
+        D: de::Deserializer<'de>,
+    {
+        struct AliasVisitor;
 
-    impl<'de> Visitor<'de> for AliasMapVisitor {
-        type Value = AliasMap;
-        fn expecting(&self, formatter: &mut Formatter) -> std::fmt::Result {
-            formatter.write_str("alias table")
-        }
-
-        fn visit_map<M>(self, mut map: M) -> std::result::Result<Self::Value, M::Error>
-        where
-            M: de::MapAccess<'de>,
-        {
-            let mut aliases = AliasMap::new();
-            while let Some(plugin) = map.next_key::<String>()? {
-                let fa: BackendArg = plugin.as_str().into();
-                let plugin_aliases = aliases.entry(fa).or_default();
-                for (from, to) in map.next_value::<BTreeMap<String, String>>()? {
-                    plugin_aliases.insert(from, to);
-                }
+        impl<'de> Visitor<'de> for AliasVisitor {
+            type Value = Alias;
+            fn expecting(&self, formatter: &mut Formatter) -> std::fmt::Result {
+                formatter.write_str("alias")
             }
-            Ok(aliases)
-        }
-    }
 
-    deserializer.deserialize_map(AliasMapVisitor)
+            fn visit_str<E>(self, v: &str) -> Result<Self::Value, E>
+            where
+                E: de::Error,
+            {
+                Ok(Alias {
+                    full: Some(v.to_string()),
+                    ..Default::default()
+                })
+            }
+
+            fn visit_map<M>(self, mut map: M) -> Result<Self::Value, M::Error>
+            where
+                M: de::MapAccess<'de>,
+            {
+                let mut full = None;
+                let mut versions = IndexMap::new();
+                while let Some(key) = map.next_key::<String>()? {
+                    match key.as_str() {
+                        "full" => {
+                            full = Some(map.next_value()?);
+                        }
+                        "versions" => {
+                            versions = map.next_value()?;
+                        }
+                        _ => {
+                            deprecated!("TOOL_VERSION_ALIASES", "tool version aliases should be `alias.<TOOL>.versions.<FROM> = <TO>`, not `alias.<TOOL>.<FROM> = <TO>`");
+                            versions.insert(key, map.next_value()?);
+                        }
+                    }
+                }
+                Ok(Alias { full, versions })
+            }
+        }
+
+        deserializer.deserialize_any(AliasVisitor)
+    }
 }
 
 #[cfg(test)]
@@ -983,7 +1053,7 @@ mod tests {
         let dump = cf.dump().unwrap();
         let env = parse_env(file::read_to_string(&p).unwrap());
 
-        assert_debug_snapshot!(env, @r###""foo=bar\nfoo2=qux\\nquux\nfoo3=qux\nquux""###);
+        assert_debug_snapshot!(env, @r#""foo=bar\nfoo2=qux\\nquux\nfoo3=qux\nquux""#);
         let cf: Box<dyn ConfigFile> = Box::new(cf);
         with_settings!({
             assert_snapshot!(dump);
@@ -1007,13 +1077,13 @@ mod tests {
         bar2="qux\nquux"
         "#});
 
-        assert_snapshot!(env, @r###"
+        assert_snapshot!(env, @r"
         foo=bar
         bar=baz
         foo2=qux\nquux
         bar2=qux
         quux
-        "###);
+        ");
     }
 
     #[test]
@@ -1025,11 +1095,11 @@ mod tests {
             foo="bar"
             "#});
 
-        assert_snapshot!(env, @r###"
+        assert_snapshot!(env, @r"
         path_add /foo
         path_add ./bar
         foo=bar
-        "###);
+        ");
 
         let env = parse_env(formatdoc! {r#"
             env_path="./bar"
@@ -1040,16 +1110,16 @@ mod tests {
             [env]
             _.path = "./bar"
             "#});
-        assert_debug_snapshot!(env, @r###""path_add ./bar""###);
+        assert_debug_snapshot!(env, @r#""path_add ./bar""#);
 
         let env = parse_env(formatdoc! {r#"
             [env]
             _.path = ["/foo", "./bar"]
             "#});
-        assert_snapshot!(env, @r###"
+        assert_snapshot!(env, @r"
         path_add /foo
         path_add ./bar
-        "###);
+        ");
 
         let env = parse_env(formatdoc! {r#"
             [[env]]
@@ -1057,20 +1127,20 @@ mod tests {
             [[env]]
             _.path = "./bar"
             "#});
-        assert_snapshot!(env, @r###"
+        assert_snapshot!(env, @r"
         path_add /foo
         path_add ./bar
-        "###);
+        ");
 
         let env = parse_env(formatdoc! {r#"
             env_path = "/foo"
             [env]
             _.path = "./bar"
             "#});
-        assert_snapshot!(env, @r###"
+        assert_snapshot!(env, @r"
         path_add /foo
         path_add ./bar
-        "###);
+        ");
     }
 
     #[test]
@@ -1080,31 +1150,31 @@ mod tests {
             env_file = ".env"
             "#});
 
-        assert_debug_snapshot!(env, @r###""dotenv .env""###);
+        assert_debug_snapshot!(env, @r#""dotenv .env""#);
 
         let env = parse_env(formatdoc! {r#"
             env_file=[".env", ".env2"]
             "#});
-        assert_debug_snapshot!(env, @r###""dotenv .env\ndotenv .env2""###);
+        assert_debug_snapshot!(env, @r#""dotenv .env\ndotenv .env2""#);
 
         let env = parse_env(formatdoc! {r#"
             [env]
             _.file = ".env"
             "#});
-        assert_debug_snapshot!(env, @r###""dotenv .env""###);
+        assert_debug_snapshot!(env, @r#""dotenv .env""#);
 
         let env = parse_env(formatdoc! {r#"
             [env]
             _.file = [".env", ".env2"]
             "#});
-        assert_debug_snapshot!(env, @r###""dotenv .env\ndotenv .env2""###);
+        assert_debug_snapshot!(env, @r#""dotenv .env\ndotenv .env2""#);
 
         let env = parse_env(formatdoc! {r#"
             dotenv = ".env"
             [env]
             _.file = ".env2"
             "#});
-        assert_debug_snapshot!(env, @r###""dotenv .env\ndotenv .env2""###);
+        assert_debug_snapshot!(env, @r#""dotenv .env\ndotenv .env2""#);
     }
 
     #[test]
@@ -1114,7 +1184,7 @@ mod tests {
         file::write(
             &p,
             formatdoc! {r#"
-            [alias.node]
+            [alias.node.versions]
             16 = "16.0.0"
             18 = "18.0.0"
         "#},
@@ -1140,11 +1210,11 @@ mod tests {
         file::write(
             &p,
             formatdoc! {r#"
-            [alias.node]
+            [alias.node.versions]
             16 = "16.0.0"
             18 = "18.0.0"
 
-            [alias.python]
+            [alias.python.versions]
             "3.10" = "3.10.0"
             "#},
         )
@@ -1228,14 +1298,14 @@ mod tests {
         _.file=".env"
         foo3="3"
         "#};
-        assert_snapshot!(parse_env(toml), @r###"
+        assert_snapshot!(parse_env(toml), @r"
         foo1=1
         unset rm
         path_add /foo
         dotenv .env
         foo2=2
         foo3=3
-        "###);
+        ");
     }
 
     #[test]
@@ -1260,7 +1330,7 @@ mod tests {
         foo6="6"
         _.source="/baz2"
         "#};
-        assert_snapshot!(parse_env(toml), @r###"
+        assert_snapshot!(parse_env(toml), @r"
         foo1=1
         unset rm
         path_add /foo
@@ -1275,7 +1345,7 @@ mod tests {
         source /baz2
         foo5=5
         foo6=6
-        "###);
+        ");
     }
 
     fn parse(s: String) -> MiseToml {
