@@ -1,5 +1,8 @@
 #[cfg(feature = "timings")]
 use crate::ui::style;
+use once_cell::sync::Lazy;
+use std::collections::HashSet;
+use std::sync::Mutex;
 
 #[cfg(test)]
 #[macro_export]
@@ -193,6 +196,17 @@ macro_rules! error {
     }};
 }
 
+pub static DEPRECATED: Lazy<Mutex<HashSet<&'static str>>> = Lazy::new(Default::default);
+
+#[macro_export]
+macro_rules! deprecated {
+    ($id:tt, $($arg:tt)*) => {{
+        if $crate::output::DEPRECATED.lock().unwrap().insert($id) {
+            warn!("deprecated [{}]: {}", $id, format!($($arg)*));
+        }
+    }};
+}
+
 #[cfg(test)]
 pub mod tests {
     use std::sync::Mutex;
